@@ -2,7 +2,7 @@
  * Programmer(s): Radu Serban @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2020, Lawrence Livermore National Security
+ * Copyright (c) 2002-2022, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -228,6 +228,9 @@ static void v_sum_prods(realtype u[], realtype p[], realtype q[], realtype v[],
 static void v_prod(realtype u[], realtype v[], realtype w[], int n);
 static void v_zero(realtype u[], int n);
 
+/* SUNDIALS context */
+static SUNContext sunctx;
+
 /*
  *--------------------------------------------------------------------
  * MAIN PROGRAM
@@ -254,6 +257,10 @@ int main(int argc, char *argv[])
   cvode_mem = NULL;
   LS = LSB = NULL;
 
+  /* Create the SUNDIALS simulation context that all SUNDIALS objects require */
+  retval = SUNContext_Create(NULL, &sunctx);
+  if (check_retval(&retval, "SUNContext_Create", 1)) return(1);
+
   /* Allocate and initialize user data */
 
   wdata = AllocUserData();
@@ -263,13 +270,13 @@ int main(int argc, char *argv[])
   /* Set-up forward problem */
 
   /* Initializations */
-  c = N_VNew_Serial(NEQ);
+  c = N_VNew_Serial(NEQ, sunctx);
   if(check_retval((void *)c, "N_VNew_Serial", 0)) return(1);
   CInit(c, wdata);
 
   /* Call CVodeCreate/CVodeInit for forward run */
   printf("\nCreate and allocate CVODES memory for forward run\n");
-  cvode_mem = CVodeCreate(CV_BDF);
+  cvode_mem = CVodeCreate(CV_BDF, sunctx);
   if(check_retval((void *)cvode_mem, "CVodeCreate", 0)) return(1);
   wdata->cvode_mem = cvode_mem; /* Used in Precond */
   retval = CVodeSetUserData(cvode_mem, wdata);
@@ -280,7 +287,7 @@ int main(int argc, char *argv[])
   if(check_retval(&retval, "CVodeSStolerances", 1)) return(1);
 
   /* Create SUNLinSol_SPGMR linear solver for forward run */
-  LS = SUNLinSol_SPGMR(c, PREC_LEFT, 0);
+  LS = SUNLinSol_SPGMR(c, SUN_PREC_LEFT, 0, sunctx);
   if(check_retval((void *)LS, "SUNLinSol_SPGMR", 0)) return(1);
 
   /* Attach the linear sovler */
@@ -291,6 +298,12 @@ int main(int argc, char *argv[])
   retval = CVodeSetPreconditioner(cvode_mem, Precond, PSolve);
   if(check_retval(&retval, "CVodeSetPreconditioner", 1)) return(1);
 
+  /* Call CVodeSetMaxNumSteps to set the maximum number of steps the
+   * solver will take in an attempt to reach the next output time
+   * during forward integration. */
+  retval = CVodeSetMaxNumSteps(cvode_mem, 2500);
+  if(check_retval(&retval, "CVodeSetMaxNumSteps", 1)) return(1);
+
   /* Set-up adjoint calculations */
 
   printf("\nAllocate global memory\n");
@@ -317,7 +330,7 @@ int main(int argc, char *argv[])
   /* Set-up backward problem */
 
   /* Allocate cB */
-  cB = N_VNew_Serial(NEQ);
+  cB = N_VNew_Serial(NEQ, sunctx);
   if(check_retval((void *)cB, "N_VNew_Serial", 0)) return(1);
   /* Initialize cB = 0 */
   CbInit(cB, ISPEC, wdata);
@@ -336,7 +349,7 @@ int main(int argc, char *argv[])
   wdata->indexB = indexB;
 
   /* Create SUNLinSol_SPGMR linear solver for backward run */
-  LSB = SUNLinSol_SPGMR(cB, PREC_LEFT, 0);
+  LSB = SUNLinSol_SPGMR(cB, SUN_PREC_LEFT, 0, sunctx);
   if(check_retval((void *)LSB, "SUNLinSol_SPGMR", 0)) return(1);
 
   /* Attach the linear sovler */
@@ -365,7 +378,7 @@ int main(int argc, char *argv[])
   N_VDestroy(cB);
   SUNLinSolFree(LS);
   SUNLinSolFree(LSB);
-
+  SUNContext_Free(&sunctx);
   FreeUserData(wdata);
 
   return(0);
@@ -436,16 +449,18 @@ static int f(realtype t, N_Vector c, N_Vector cdot, void *user_data)
 
 /*
  * This routine generates the block-diagonal part of the Jacobian
- * corresponding to the interaction rates, multiplies by -gamma, adds
- * the identity matrix, and calls denseGETRF to do the LU decomposition of
- * each diagonal block. The computation of the diagonal blocks uses
- * the preset block and grouping information. One block per group is
- * computed. The Jacobian elements are generated by difference
- * quotients using calls to the routine fblock.
+ * corresponding to the interaction rates, multiplies by -gamma,
+ * adds the identity matrix, and calls SUNDlsMat_denseGETRF to do
+ * the LU decomposition of each diagonal block. The computation of
+ * the diagonal blocks uses the preset block and grouping
+ * information. One block per group is computed. The Jacobian
+ * elements are generated by difference quotients using calls to the
+ * routine fblock.
  *
  * This routine can be regarded as a prototype for the general case
- * of a block-diagonal preconditioner. The blocks are of size mp, and
- * there are ngrp=ngx*ngy blocks computed in the block-grouping scheme.
+ * of a block-diagonal preconditioner. The blocks are of size mp,
+ * and there are ngrp=ngx*ngy blocks computed in the block-grouping
+ * scheme.
  */
 
 static int Precond(realtype t, N_Vector c, N_Vector fc,
@@ -521,8 +536,8 @@ static int Precond(realtype t, N_Vector c, N_Vector fc,
   /* Add identity matrix and do LU decompositions on blocks. */
 
    for (ig = 0; ig < ngrp; ig++) {
-     denseAddIdentity(P[ig], mp);
-     denseretval = denseGETRF(P[ig], mp, mp, pivot[ig]);
+     SUNDlsMat_denseAddIdentity(P[ig], mp);
+     denseretval = SUNDlsMat_denseGETRF(P[ig], mp, mp, pivot[ig]);
      if (denseretval != 0) return(1);
    }
 
@@ -576,7 +591,7 @@ static int PSolve(realtype t, N_Vector c, N_Vector fc,
     for (jx = 0; jx < mx; jx++) {
       igx = jigx[jx];
       ig = igx + igy*ngx;
-      denseGETRS(P[ig], mp, pivot[ig], &(N_VGetArrayPointer(z)[iv]));
+      SUNDlsMat_denseGETRS(P[ig], mp, pivot[ig], &(N_VGetArrayPointer(z)[iv]));
       iv += mp;
     }
   }
@@ -726,8 +741,8 @@ static int PrecondB(realtype t, N_Vector c,
   /* Add identity matrix and do LU decompositions on blocks. */
 
    for (ig = 0; ig < ngrp; ig++) {
-     denseAddIdentity(P[ig], mp);
-     denseretval = denseGETRF(P[ig], mp, mp, pivot[ig]);
+     SUNDlsMat_denseAddIdentity(P[ig], mp);
+     denseretval = SUNDlsMat_denseGETRF(P[ig], mp, mp, pivot[ig]);
      if (denseretval != 0) return(1);
    }
 
@@ -775,7 +790,7 @@ static int PSolveB(realtype t, N_Vector c,
     for (jx = 0; jx < mx; jx++) {
       igx = jigx[jx];
       ig = igx + igy*ngx;
-      denseGETRS(P[ig], mp, pivot[ig], &(N_VGetArrayPointer(z)[iv]));
+      SUNDlsMat_denseGETRS(P[ig], mp, pivot[ig], &(N_VGetArrayPointer(z)[iv]));
       iv += mp;
     }
   }
@@ -801,11 +816,11 @@ static WebData AllocUserData(void)
 
   wdata = (WebData) malloc(sizeof *wdata);
   for(i=0; i < ngrp; i++) {
-    (wdata->P)[i] = newDenseMat(ns, ns);
-    (wdata->pivot)[i] = newIndexArray(ns);
+    (wdata->P)[i] = SUNDlsMat_newDenseMat(ns, ns);
+    (wdata->pivot)[i] = SUNDlsMat_newIndexArray(ns);
   }
-  wdata->rewt  = N_VNew_Serial(NEQ);
-  wdata->vtemp = N_VNew_Serial(NEQ);
+  wdata->rewt  = N_VNew_Serial(NEQ, sunctx);
+  wdata->vtemp = N_VNew_Serial(NEQ, sunctx);
 
   return(wdata);
 }
@@ -1346,8 +1361,8 @@ static void FreeUserData(WebData wdata)
 
   ngrp = wdata->ngrp;
   for(i=0; i < ngrp; i++) {
-    destroyMat((wdata->P)[i]);
-    destroyArray((wdata->pivot)[i]);
+    SUNDlsMat_destroyMat((wdata->P)[i]);
+    SUNDlsMat_destroyArray((wdata->pivot)[i]);
   }
   N_VDestroy(wdata->rewt);
   N_VDestroy(wdata->vtemp);
