@@ -2,15 +2,15 @@
  * Programmer(s): Allan Taylor, Alan Hindmarsh and
  *                Radu Serban @ LLNL
  * -----------------------------------------------------------------
- * LLNS Copyright Start
- * Copyright (c) 2017, Lawrence Livermore National Security
- * This work was performed under the auspices of the U.S. Department 
- * of Energy by Lawrence Livermore National Laboratory in part under 
- * Contract W-7405-Eng-48 and in part under Contract DE-AC52-07NA27344.
- * Produced at the Lawrence Livermore National Laboratory.
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2022, Lawrence Livermore National Security
+ * and Southern Methodist University.
  * All rights reserved.
- * For details, see the LICENSE file.
- * LLNS Copyright End
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
  * -----------------------------------------------------------------
  * Example program for IDA: Food web problem.
  *
@@ -182,6 +182,7 @@ int main()
   realtype rtol, atol, t0, tout, tret;
   SUNMatrix A;
   SUNLinearSolver LS;
+  SUNContext ctx;
 
   mem = NULL;
   webdata = NULL;
@@ -189,23 +190,27 @@ int main()
   A = NULL;
   LS = NULL;
 
+  /* Create the SUNDIALS context object for this simulation */
+  retval = SUNContext_Create(NULL, &ctx);
+  if (check_retval(&retval, "SUNContext_Create", 1)) return 1;
+
   /* Allocate and initialize user data block webdata. */
 
   webdata = (UserData) malloc(sizeof *webdata);
-  webdata->rates = N_VNew_Serial(NEQ);
-  webdata->acoef = newDenseMat(NUM_SPECIES, NUM_SPECIES);
+  webdata->rates = N_VNew_Serial(NEQ, ctx);
+  webdata->acoef = SUNDlsMat_newDenseMat(NUM_SPECIES, NUM_SPECIES);
 
   InitUserData(webdata);
 
   /* Allocate N-vectors and initialize cc, cp, and id. */
 
-  cc  = N_VNew_Serial(NEQ);
+  cc  = N_VNew_Serial(NEQ, ctx);
   if(check_retval((void *)cc, "N_VNew_Serial", 0)) return(1);
 
-  cp  = N_VNew_Serial(NEQ);
+  cp  = N_VNew_Serial(NEQ, ctx);
   if(check_retval((void *)cp, "N_VNew_Serial", 0)) return(1);
 
-  id  = N_VNew_Serial(NEQ);
+  id  = N_VNew_Serial(NEQ, ctx);
   if(check_retval((void *)id, "N_VNew_Serial", 0)) return(1);
 
   SetInitialProfiles(cc, cp, id, webdata);
@@ -218,7 +223,7 @@ int main()
 
   /* Call IDACreate and IDAMalloc to initialize IDA. */
 
-  mem = IDACreate();
+  mem = IDACreate(ctx);
   if(check_retval((void *)mem, "IDACreate", 0)) return(1);
 
   retval = IDASetUserData(mem, webdata);
@@ -235,11 +240,11 @@ int main()
 
   /* Create banded SUNMatrix for use in linear solves */
   mu = ml = NSMX;
-  A = SUNBandMatrix(NEQ, mu, ml);
+  A = SUNBandMatrix(NEQ, mu, ml, ctx);
   if(check_retval((void *)A, "SUNBandMatrix", 0)) return(1);
 
   /* Create banded SUNLinearSolver object */
-  LS = SUNLinSol_Band(cc, A);
+  LS = SUNLinSol_Band(cc, A, ctx);
   if(check_retval((void *)LS, "SUNLinSol_Band", 0)) return(1);
 
   /* Attach the matrix and linear solver */
@@ -285,10 +290,12 @@ int main()
   N_VDestroy(id);
 
 
-  destroyMat(webdata->acoef);
+  SUNDlsMat_destroyMat(webdata->acoef);
   N_VDestroy(webdata->rates);
   free(webdata);
 
+  SUNContext_Free(&ctx);
+
   return(0);
 }
 
@@ -360,7 +367,7 @@ static int resweb(realtype tt, N_Vector cc, N_Vector cp,
 
 static void InitUserData(UserData webdata)
 {
-  int i, j, np;
+  sunindextype i, j, np;
   realtype *a1,*a2, *a3, *a4, dx2, dy2;
 
   webdata->mx = MX;
